///////////////////////////////////////////////////////////////////////
//
// TaShell.cpp : implementation of techexplorer AddIn functions
//
///////////////////////////////////////////////////////////////////////
//
// Copyright (c) 1997-98 by the IBM Corporation. All Rights Reserved
//
// Author:          Angel L. Diaz     aldiaz@us.ibm.com
//                  Robert S. Sutor   sutor@us.ibm.com
//
// IBM MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
// THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
// TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
// PARTICULAR PURPOSE, OR NON-INFRINGEMENT. IBM SHALL NOT BE LIABLE FOR
// ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING OR MODIFYING
// THIS SOFTWARE OR ITS DERIVATIVES.
//
///////////////////////////////////////////////////////////////////////

//====================================================================
// This file implements the functions required of a techexplorer AddIn.
// It translates the IBM techexplorer API calls to code specific for
// the Simple Add-in. 
//
// Note: If this DLL is dynamically linked against the MFC DLLs, any 
// functions exported from this DLL which call into MFC must have the 
// AFX_MANAGE_STATE macro added at the very beginning of the function
// (MFC Technical Notes 33 and 58).
//====================================================================

#include "StdAfx.h"
#include "TAMthLnk.h"

#ifdef __cplusplus
extern "C" {
#endif

//====================================================================
// AddInGetMIMEDescription: Return the MIME type(s) supported by 
//    an add-in, as well as descriptive information
//====================================================================

LPCSTR 
AddInGetMIMEDescription( )
{
	/* techexplorer calls the AddInGetMIMEDescription add-in function to 
	 * retrieve the MIME type(s) supported by an add-in, as well as 
	 * descriptive information about the add-in. Note that this is called
	 * at run time to allow an add-in to dynamically modify embedded add-in
     * information.
     *
     * A remark regarding resources: The add-in 
     *
     *    MIME type; file extension; add-in description | ...
     *
     * triple must be defined in the add-in version information as the
     * value of the MIMEDescription attribute (see TAMthLnk.rc). It is
     * necessary that the language for the version information be specified
     * as "English (United States)" and the Code Page set to 
     * "Windows, Multilingual" (040904e4). If either of these specifications
     * are not implemented, the add-in will not be registered with
     * techexplorer. 
	 */
	AFX_MANAGE_STATE(AfxGetStaticModuleState());
	return CTAMthLnkApp::GetAddInDllObject()->GetMimeType( );
}

//====================================================================
// AddInInitialize: Initialize the add-in
//====================================================================

TAError 
AddInInitialize( )
{	
   /* This function is called by techexplorer only once and prior to any 
    * other add-in API method being invoked. This should be used for 
	* "global" initializations, that is initializations that are shared 
	* across add-in instances and are not tied to a particular instance.
    */
	AFX_MANAGE_STATE(AfxGetStaticModuleState());
	return CTAMthLnkApp::GetAddInDllObject()->Initialize();
}

//====================================================================
// AddInShutdown: Shut down the add-in, freeing any resources
//====================================================================

void
AddInShutdown( )
{
   /* This function is invoked immediately before an add-in is unloaded 
    * from memory. Add-in instance specific data and resources should 
	* be released.	Remember to delete any remaining add-in allocated 
    * instance data (pAddInInstance->pAddIn), since AddInDestroy may 
    * not have been called if the shutdown request came from Java.
    */
	AFX_MANAGE_STATE(AfxGetStaticModuleState());
	CTAMthLnkApp::GetAddInDllObject()->Shutdown();
}

//====================================================================
// AddInNew: Initialize an add-in instance
//====================================================================

TAError
AddInNew(AddInInstance *pAddInInstance, LPCSTR sMimeType)
{
   /* For each instance, techexplorer calls the AddInNew function. The 
    * AddInInstance pointer uniquely identifies a particular add-in
    * instance and is used in subsequent function calls between 
	* techexplorer and add-ins to identify a particular instance.
    */
	AFX_MANAGE_STATE(AfxGetStaticModuleState());
	return CTAMthLnkApp::GetAddInDllObject()->New(pAddInInstance, sMimeType);
}

//====================================================================
// AddInDestroy: Free resources associated with an add-in instance
//====================================================================

TAError 
AddInDestroy(AddInInstance *pAddInInstance)
{
   /* When an instance is destroyed, the AddInDestroy function is
    * invoked. When the last instance of an add-in is destroyed, 
	* techexplorer calls AddInShutdown. Do not delete pAddInInstance! 
	* techexplorer allocates/deallocates the instance pointer 
	*/
   	AFX_MANAGE_STATE(AfxGetStaticModuleState());
	return CTAMthLnkApp::GetAddInDllObject()->Destroy(pAddInInstance);
}

//====================================================================
// AddInEvaluate: Process application specific data
//====================================================================

TAError 
AddInEvaluate(AddInInstance *pAddInInstance, LPCSTR sMimeType, LPCSTR sAppInput)
{
    /* The AddInEvaluate function is used for receiving application specific 
     * data from a techexplorer document or Java applet. The pAddInInstance 
     * and smimeType identifies a particular add-in instance and data type 
     * respectively. In the case of an "evaluate" request from Java, 
     * pAddInInstance will be NULL for version 2.0 of the add-in and 
     * Java API. In this case handle the request in a default manner.  
     */
	AFX_MANAGE_STATE(AfxGetStaticModuleState());
	return CTAMthLnkApp::GetAddInDllObject()->Evaluate(pAddInInstance, sMimeType, sAppInput );
}

//====================================================================
// AddInLocalFileIsReady: Called when a requested URL is available
//====================================================================

TAError
AddInLocalFileIsReady(AddInInstance *pAddInInstance, LPCSTR sFileName)
{
    /* The AddInLocalFileIsReady function provides the path of the a
     * local file containing the data requested by a 
     * techexplorerGetLocalFileNameForURL invocation.
     * Note that if the URL is not avaliable this call will never be
     * invoked.
     */
	AFX_MANAGE_STATE(AfxGetStaticModuleState());
	return CTAMthLnkApp::GetAddInDllObject()->LocalFileIsReady(pAddInInstance, sFileName);
}

#ifdef __cplusplus
}  /* end extern "C" */
#endif
